==> roboter-5.0.0.tgz: package/lib/cli/commands/release.js <==
'use strict';

const path = require('path');

const documentation = require('../../automation/documentation'),
      files = require('../../files'),
      git = require('../../automation/git'),
      globalOptionDefinitions = require('../globalOptionDefinitions'),
      pkg = require('../../automation/pkg'),
      quality = require('../../automation/quality'),
      ui = require('../ui');

const release = {
  description: 'Release a new version.',

  async getOptionDefinitions () {
    return [
      {
        name: 'force',
        alias: 'f',
        type: Boolean,
        defaultValue: false,
        description: 'Release without running tests, code analysis etc.'
      },
      {
        name: 'type',
        alias: 't',
        type: String,
        defaultValue: 'patch',
        description: 'patch, minor or major'
      }
    ];
  },

  async run (options) {
    if (!options) {
      throw new Error('Options are missing.');
    }
    if (options.type === undefined) {
      throw new Error('Type is missing.');
    }

    const directory = process.cwd(),
          { help, force, type } = options;

    const packageJsonPath = path.join(directory, 'package.json');

    if (help) {
      return ui.printUsage([
        { header: 'roboter release', content: this.description },
        { header: 'Synopsis', content: 'roboter release [--type <patch|minor|major>] [--force]' },
        { header: 'Options', optionList: [ ...await this.getOptionDefinitions(), ...globalOptionDefinitions ]}
      ]);
    }

    ui.printTaskHeader('release');

    try {
      if (!force) {
        try {
          await quality.analyseCode({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ECODEMALFORMED':
              ui.printTaskFailure('Code analysis failed.');
              break;
            default:
              ui.printTaskFailure('Failed to run code analysis.');
              break;
          }
          throw ex;
        }

        try {
          await quality.testCode({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ETESTSMISSING':
              ui.warn('No tests found.');
              break;
            case 'ETESTSFAILED':
              ui.printTaskFailure('Tests failed.');
              throw ex;
            default:
              ui.printTaskFailure('Failed to run tests.');
              throw ex;
          }
        }

        try {
          await pkg.checkForUnusedDependencies({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'EUNUSEDDEPENDENCIES':
              break;
            default:
              throw ex;
          }
        }

        try {
          await pkg.checkForOutdatedDependencies({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'EOUTDATEDDEPENDENCIES':
              break;
            default:
              throw ex;
          }
        }

        try {
          await pkg.checkLicenseCompatibility({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ELICENSEINCOMPATIBLE':
              throw ex;
            case 'ELICENSENOTSUPPORTED':
              break;
            default:
              throw ex;
          }
        }
      }

      await git.checkIfOnMaster({ directory, ui });
      await git.checkForPendingChanges({ directory, ui });
      await git.checkIfLocalMasterIsBehindRemote({ directory, ui });

      const readMePath = path.join(directory, 'README.md');
      const hasReadMe = await files.exists({ path: readMePath });

      if (hasReadMe) {
        await documentation.generateTocForMarkdown({ path: readMePath, ui });
      }

      const sourcePath = path.join(directory, 'src');
      const hasSourceDirectory = await files.exists({ path: sourcePath });

      if (hasSourceDirectory) {
        await pkg.precompile({ directory, sourcePath, distributionPath: path.join(directory, 'dist'), ui });
      }

      const versions = await pkg.bumpVersion({ path: packageJsonPath, type, ui });

      await git.commitChanges({ directory, message: `Release ${versions.new}.`, ui });
      await git.tag({ directory, name: versions.new, message: `Create tag for version ${versions.new}.`, ui });
      await git.push({ directory, remote: 'origin', branch: 'master', pushTags: true, ui });

      ui.printTaskSuccess(`Successfully released version ${versions.new}.`);
    } catch (ex) {
      switch (ex.code) {
        case 'ENOTONLOCALMASTER':
          ui.printTaskFailure(`You must be on the 'master' branch, run 'git checkout master' first.`);
          break;
        case 'ELOCALMASTERBEHINDREMOTE':
          ui.printTaskFailure(`The local master branch is behind origin/master, run 'git pull' first.`);
          break;
        case 'EPACKAGEJSONMISSING':
          ui.printTaskFailure(`No package.json found, run 'npm init' to create one.`);
          break;
        case 'EPENDINGCHANGES':
          ui.printTaskFailure('You have pending changes, commit your changes first.');
          break;
        default:
          ui.printTaskFailure('Failed to release.');
      }

      throw ex;
    }
  }
};

module.exports = release;

==> roboter-7.0.1.tgz: package/lib/cli/commands/release.js <==
'use strict';

const path = require('path');

const isTypeScript = require('is-typescript');

const documentation = require('../../automation/documentation'),
      files = require('../../files'),
      git = require('../../automation/git'),
      globalOptionDefinitions = require('../globalOptionDefinitions'),
      pkg = require('../../automation/pkg'),
      quality = require('../../automation/quality'),
      ui = require('../ui');

const release = {
  description: 'Release a new version.',

  async getOptionDefinitions () {
    return [
      {
        name: 'force',
        alias: 'f',
        type: Boolean,
        defaultValue: false,
        description: 'Release without running tests, code analysis etc.'
      },
      {
        name: 'type',
        alias: 't',
        type: String,
        defaultValue: 'patch',
        description: 'patch, minor or major'
      }
    ];
  },

  async run (options) {
    if (!options) {
      throw new Error('Options are missing.');
    }
    if (options.type === undefined) {
      throw new Error('Type is missing.');
    }

    const directory = process.cwd(),
          { help, force, type } = options;

    const packageJsonPath = path.join(directory, 'package.json');

    if (help) {
      return ui.printUsage([
        { header: 'roboter release', content: this.description },
        { header: 'Synopsis', content: 'roboter release [--type <patch|minor|major>] [--force]' },
        { header: 'Options', optionList: [ ...await this.getOptionDefinitions(), ...globalOptionDefinitions ]}
      ]);
    }

    ui.printTaskHeader('release');

    try {
      if (!force) {
        try {
          await quality.analyseCode({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ECODEMALFORMED':
              ui.printTaskFailure('Code analysis failed.');
              break;
            default:
              ui.printTaskFailure('Failed to run code analysis.');
              break;
          }
          throw ex;
        }

        try {
          await quality.testCode({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ETESTSMISSING':
              ui.warn('No tests found.');
              break;
            case 'ETESTSFAILED':
              ui.printTaskFailure('Tests failed.');
              throw ex;
            default:
              ui.printTaskFailure('Failed to run tests.');
              throw ex;
          }
        }

        try {
          await pkg.checkForUnusedDependencies({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'EUNUSEDDEPENDENCIES':
              break;
            default:
              throw ex;
          }
        }

        try {
          await pkg.checkForOutdatedDependencies({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'EOUTDATEDDEPENDENCIES':
              break;
            default:
              throw ex;
          }
        }

        try {
          await pkg.checkLicenseCompatibility({ directory, ui });
        } catch (ex) {
          switch (ex.code) {
            case 'ELICENSEINCOMPATIBLE':
              throw ex;
            case 'ELICENSENOTSUPPORTED':
              break;
            default:
              throw ex;
          }
        }
      }

      await git.checkIfOnMaster({ directory, ui });
      await git.checkForPendingChanges({ directory, ui });
      await git.checkIfLocalMasterIsBehindRemote({ directory, ui });

      const readMePath = path.join(directory, 'README.md');
      const hasReadMe = await files.exists({ path: readMePath });

      if (hasReadMe) {
        await documentation.generateTocForMarkdown({ path: readMePath, ui });
      }

      if (isTypeScript({ directory })) {
        await pkg.precompile({ directory, ui });
      }

      const versions = await pkg.bumpVersion({ path: packageJsonPath, type, ui });

      await git.commitChanges({ directory, message: `Release ${versions.new}.`, ui });
      await git.tag({ directory, name: versions.new, message: `Create tag for version ${versions.new}.`, ui });
      await git.push({ directory, remote: 'origin', branch: 'master', pushTags: true, ui });

      ui.printTaskSuccess(`Successfully released version ${versions.new}.`);
    } catch (ex) {
      switch (ex.code) {
        case 'ENOTONLOCALMASTER':
          ui.printTaskFailure(`You must be on the 'master' branch, run 'git checkout master' first.`);
          break;
        case 'ELOCALMASTERBEHINDREMOTE':
          ui.printTaskFailure(`The local master branch is behind origin/master, run 'git pull' first.`);
          break;
        case 'EPACKAGEJSONMISSING':
          ui.printTaskFailure(`No package.json found, run 'npm init' to create one.`);
          break;
        case 'EPENDINGCHANGES':
          ui.printTaskFailure('You have pending changes, commit your changes first.');
          break;
        default:
          ui.printTaskFailure('Failed to release.');
      }

      throw ex;
    }
  }
};

module.exports = release;
